//
//  CustomMsgFormViewController.swift
//  app
//
//  Created by Luis Quiñones  on 11/30/19.
//  Copyright © 2019 Luis Quiñones . All rights reserved.
//

import UIKit

class CustomMsgFormViewController: UIViewController {

        let defaults = UserDefaults.standard
        var event: String?
        var eventDict: [String:Any] = [:]
        
        fileprivate let riskLevelPicker = UIPickerView()
        fileprivate let freqPicker = UIPickerView()
        fileprivate let durationPicker = UIPickerView()
        
        let riskLevelPickerData = [String](arrayLiteral: "No veo riesgo al momento.", "Percibo un riesgo moderado.", "La situación está escalando.", "Me preocupa mi bienestar, el peligro es inminente.")
        
        let freqPickerData = [String](arrayLiteral: "5","10", "15","30")
        let durationPickerData = [String](arrayLiteral: "1/2","1","3","5")
        
        @IBOutlet weak var eventTitle: UILabel!
        
        @IBOutlet weak var msgTextView: UITextView!
        
        @IBOutlet weak var riskLevelTextField: UITextField!
        
        @IBOutlet weak var eventDurationField: UITextField!
        @IBOutlet weak var msgFreqField: UITextField!
        @IBAction func locationPrefBox(_ sender: UIButton) {
            sender.isSelected = !sender.isSelected
        }
        
        @IBOutlet weak var locationPrefBtn: UIButton!
        
        // MARK: - Save Button
        @IBAction func saveMsgForm(_ sender: Any) {
            guard let msg = msgTextView.text else {
                print("Missing msg in form.")
                return
            }
            guard let riskLevel = riskLevelTextField.text else {
                print("Missing riskLevel in form.")
                return
            }
            guard let eventDuration = eventDurationField.text else {
                print("Missing eventDuration in form.")
                return
            }
            guard let msgFreq = msgFreqField.text else {
                print("Missing msgFreq in form.")
                return
            }
    //        if msgTextView.text.isEmpty || riskLevelTextField.text!.isEmpty || msgFreqField.text!.isEmpty || eventDurationField.text!.isEmpty {
    //
    //            // alert missing field
    //
    //        }
            
            
            // Form is valid
            eventDict["msg"] = msg
            eventDict["riskLevel"] = riskLevel
            eventDict["eventDuration"] = eventDuration
            eventDict["msgFreq"] = msgFreq
            eventDict["locationPref"] = !locationPrefBtn.isSelected
            defaults.set(eventDict, forKey: event!)
        }
        
        @IBOutlet weak var saveMsgFormBtn: UIButton!
        
        // MARK: - viewDidLoad
        override func viewDidLoad() {
            super.viewDidLoad()
            // Do any additional setup after loading the view.

            switch event {
                case "deCamino":
                    self.eventTitle.text = "De camino"
                case "soleao":
                    self.eventTitle.text = "Ando soleá/o"
                case "aPie":
                    self.eventTitle.text = "Me quedé a pie"
                default:
                    self.eventTitle.text = "Personalizado"
            }
            
            let toolBar = UIToolbar()
            toolBar.sizeToFit()
            let button = UIBarButtonItem(title: "Done", style: .plain, target: self, action: #selector(self.action))
            toolBar.setItems([button], animated: true)
            toolBar.isUserInteractionEnabled = true
            
            
            riskLevelPicker.delegate = self
            riskLevelPicker.dataSource = self
            durationPicker.delegate = self
            durationPicker.dataSource = self
            freqPicker.delegate = self
            freqPicker.dataSource = self

            
            riskLevelTextField.inputView = riskLevelPicker
            riskLevelTextField.inputAccessoryView = toolBar
            eventDurationField.inputView = durationPicker
            eventDurationField.inputAccessoryView = toolBar
            msgFreqField.inputView = freqPicker
            msgFreqField.inputAccessoryView = toolBar
            
            eventDict = defaults.object(forKey: event!) as? [String: Any] ?? [String: Any]()
            
            // by default reload and enable form
            reloadAndEnableFormData()
        }
        
        @objc func action() {
              view.endEditing(true)
        }
        
        // MARK: - Reload Form Data
        func reloadAndEnableFormData() {
            
            // Load saved input
            
            eventDict = defaults.object(forKey: event!) as? [String: Any] ?? [String: Any]()
            
            msgTextView.text = eventDict["msg"] as? String
            msgTextView.isEditable = true
            
            riskLevelTextField.text = eventDict["riskLevel"] as? String
            riskLevelTextField.isEnabled = true
            
            eventDurationField.text = eventDict["eventDuration"] as? String
            eventDurationField.isEnabled = true
            
            msgFreqField.text = eventDict["msgFreq"] as? String
            msgFreqField.isEnabled = true
            
            locationPrefBtn.isSelected = !(eventDict["locationPref"] as! Bool)
            locationPrefBtn.isEnabled = true
            
        }
}

extension CustomMsgFormViewController: UITextViewDelegate, UIPickerViewDelegate, UIPickerViewDataSource {
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        return 1
    }
    
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        
        if pickerView == riskLevelPicker {
            return riskLevelPickerData.count
        }
            
        else if pickerView == freqPicker {
            return freqPickerData.count
        }
        else {
            return durationPickerData.count
        }
    }
    
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        if pickerView == riskLevelPicker {
            riskLevelTextField.text = riskLevelPickerData[row]
        }
        else if pickerView == durationPicker {
            eventDurationField.text = durationPickerData[row]
        }
        else {
            msgFreqField.text = freqPickerData[row]
        }
    }
    
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        if pickerView == riskLevelPicker {
            return riskLevelPickerData[row]
        }
            
        else if pickerView == freqPicker {
            return freqPickerData[row]
        }
        else {
            return durationPickerData[row]
        }
    }
    
    func textView(_ textView: UITextView, shouldChangeTextIn range: NSRange, replacementText text: String) -> Bool {
           let newText = (textView.text as NSString).replacingCharacters(in: range, with: text)
           let numberOfChars = newText.count
           return numberOfChars < 100    // 100 Limit Value
       }
}
